@@ -53,8 +53,41 @@ private:
 };
 #endif
 
+void messageHandler(QtMsgType type, const QMessageLogContext &context, const QString &msg)
+{
+    Q_UNUSED(context);
+
+    QByteArray localMsg = msg.toLocal8Bit();
+    switch (type) {
+    case QtInfoMsg: {
+        QLOG_INFO() << localMsg.constData();
+        break;
+    }
+    case QtDebugMsg: {
+        QLOG_DEBUG() << localMsg.constData();
+        break;
+    }
+
+    case QtWarningMsg: {
+        QLOG_WARN() << localMsg.constData();
+        break;
+    }
+
+    case QtCriticalMsg: {
+        QLOG_ERROR() << localMsg.constData();
+        break;
+    }
+
+    case QtFatalMsg: {
+        QLOG_FATAL() << localMsg.constData();
+        break;
+    }
+    }
+}
+
 int main(int argc, char *argv[])
 {
+    qInstallMessageHandler(messageHandler);
 
 #if defined(_MSC_VER) && defined(_DEBUG)
     _CrtSetDbgFlag(_CRTDBG_ALLOC_MEM_DF | _CRTDBG_LEAK_CHECK_DF);
@@ -81,6 +114,7 @@ int main(int argc, char *argv[])
     QCommandLineParser parser;
     parser.addHelpOption();
     parser.addVersionOption();
+    parser.addOption({ "loglevel", "Set log level. Valid values: trace, info, debug, warn, error.", "loglevel", "warning" });
     parser.addPositionalArgument("[File|Directory]", "File or directory to open.");
     QCommandLineOption comicId("comicId", "", "comicId");
     QCommandLineOption libraryId("libraryId", "", "libraryId");
@@ -104,11 +138,27 @@ int main(int argc, char *argv[])
     Logger &logger = Logger::instance();
     logger.setLoggingLevel(QsLogging::InfoLevel);
 
-    DestinationPtr fileDestination(DestinationFactory::MakeFileDestination(
-            destLog, EnableLogRotation, MaxSizeBytes(1048576), MaxOldLogCount(2)));
-    DestinationPtr debugDestination(DestinationFactory::MakeDebugOutputDestination());
-    logger.addDestination(debugDestination);
-    logger.addDestination(fileDestination);
+    if (parser.isSet("loglevel")) {
+        if (parser.value("loglevel") == "trace") {
+            logger.setLoggingLevel(QsLogging::TraceLevel);
+        } else if (parser.value("loglevel") == "info") {
+            logger.setLoggingLevel(QsLogging::InfoLevel);
+        } else if (parser.value("loglevel") == "debug") {
+            logger.setLoggingLevel(QsLogging::DebugLevel);
+        } else if (parser.value("loglevel") == "warn") {
+            logger.setLoggingLevel(QsLogging::WarnLevel);
+        } else if (parser.value("loglevel") == "error") {
+            logger.setLoggingLevel(QsLogging::ErrorLevel);
+        } else {
+            parser.showHelp();
+        }
+    }
+
+    DestinationPtrU fileDestination(DestinationFactory::MakeFileDestination(
+            destLog, LogRotationOption::EnableLogRotation, MaxSizeBytes(1048576), MaxOldLogCount(2)));
+    DestinationPtrU debugDestination(DestinationFactory::MakeDebugOutputDestination());
+    logger.addDestination(std::move(debugDestination));
+    logger.addDestination(std::move(fileDestination));
 
     QTranslator translator;
     QString sufix = QLocale::system().name();
@@ -137,5 +187,8 @@ int main(int argc, char *argv[])
 
     //Configuration::getConfiguration().save();
     YACReader::exitCheck(ret);
+#ifdef Q_OS_WIN
+    logger.shutDownLoggerThread();
+#endif
     return ret;
 }
