@@ -9,23 +9,23 @@ class AddLabelDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit AddLabelDialog(QWidget *parent = 0);
+    explicit AddLabelDialog(QWidget *parent = nullptr);
     YACReader::LabelColors selectedColor();
     QString name();
 signals:
 
 public slots:
-    int exec();
+    int exec() override;
 
 protected slots:
-    void validateName(const QString & name);
+    void validateName(const QString &name);
 
 protected:
-    QLineEdit * edit;
-    QListWidget * list;
+    QLineEdit *edit;
+    QListWidget *list;
 
-    QPushButton * acceptButton;
-    QPushButton * cancelButton;
+    QPushButton *acceptButton;
+    QPushButton *cancelButton;
 };
 
 #endif // ADD_LABEL_DIALOG_H
