@@ -11,21 +11,21 @@ class ApiKeyDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit ApiKeyDialog(QWidget *parent = 0);
-    ~ApiKeyDialog();
+    explicit ApiKeyDialog(QWidget *parent = nullptr);
+    ~ApiKeyDialog() override;
 signals:
 
 public slots:
 
 protected slots:
-    void enableAccept(const QString & text);
+    void enableAccept(const QString &text);
     void saveApiKey();
 
 protected:
-    QPushButton * acceptButton;
-    QPushButton * cancelButton;
-    QLineEdit * edit;
-    QSettings * settings;
+    QPushButton *acceptButton;
+    QPushButton *cancelButton;
+    QLineEdit *edit;
+    QSettings *settings;
 };
 
 #endif // API_KEY_DIALOG_H
