@@ -5,14 +5,13 @@
 
 class ScraperTableView : public QTableView
 {
-	Q_OBJECT
+    Q_OBJECT
 public:
-	explicit ScraperTableView(QWidget *parent = 0);
+    explicit ScraperTableView(QWidget *parent = nullptr);
 
 signals:
 
 public slots:
-
 };
 
 #endif // SCRAPPER_TABLEVIEW_H
