@@ -7,11 +7,11 @@ class ComicsViewTransition : public QWidget
 {
     Q_OBJECT
 public:
-    explicit ComicsViewTransition(QWidget *parent = 0);
+    explicit ComicsViewTransition(QWidget *parent = nullptr);
     QSize sizeHint();
 
 protected:
-    void paintEvent(QPaintEvent *);
+    void paintEvent(QPaintEvent *) override;
 };
 
 #endif // COMICS_VIEW_TRANSITION_H
