@@ -1,10 +1,8 @@
 #ifndef IMPORT_WIDGET_H
 #define IMPORT_WIDGET_H
 
-
 #include <QtWidgets>
 
-
 class ImportWidget : public QWidget
 {
     Q_OBJECT
@@ -14,8 +12,8 @@ public:
 signals:
     void stop();
 public slots:
-    void newComic(const QString & path, const QString & coverPath);
-    void newCover(const QPixmap & image);
+    void newComic(const QString &path, const QString &coverPath);
+    void newCover(const QPixmap &image);
     void clear();
     void addCoverTest();
     void clearScene();
@@ -25,26 +23,25 @@ public slots:
     void showCovers(bool hide);
 
 private:
-    QLabel * currentComicLabel;
-    QLabel * coversLabel;
-    QLabel * iconLabel;
-    QLabel * text;
-    QLabel * textDescription;
-    QWidget * coversViewContainer;
-    QGraphicsView * coversView;
-    QGraphicsScene * coversScene;
-    QPropertyAnimation * scrollAnimation;
-    QPushButton * stopButton;
+    QLabel *currentComicLabel;
+    QLabel *coversLabel;
+    QLabel *iconLabel;
+    QLabel *text;
+    QLabel *textDescription;
+    QWidget *coversViewContainer;
+    QGraphicsView *coversView;
+    QGraphicsScene *coversScene;
+    QPropertyAnimation *scrollAnimation;
+    QPushButton *stopButton;
 
     int previousWidth;
     bool updatingCovers;
-    QElapsedTimer * elapsedTimer;
+    QElapsedTimer *elapsedTimer;
     quint64 i;
 
-    QToolButton * hideButton;
-
-    void resizeEvent(QResizeEvent * event);
+    QToolButton *hideButton;
 
+    void resizeEvent(QResizeEvent *event) override;
 };
 
 #endif // IMPORT_WIDGET_H
