@@ -7,7 +7,7 @@
 #include "httpresponse.h"
 #include "httprequesthandler.h"
 
-class SyncController : public HttpRequestHandler
+class SyncController : public stefanfrings::HttpRequestHandler
 {
     Q_OBJECT
     Q_DISABLE_COPY(SyncController)
@@ -16,7 +16,7 @@ public:
     SyncController();
 
     /** Generates the response */
-    void service(HttpRequest &request, HttpResponse &response) override;
+    void service(stefanfrings::HttpRequest &request, stefanfrings::HttpResponse &response) override;
 };
 
 #endif // SYNCCONTROLLER_H
