@@ -11,7 +11,11 @@
 
 #include "QsLog.h"
 
-UpdateComicController::UpdateComicController() {}
+using stefanfrings::HttpRequest;
+using stefanfrings::HttpResponse;
+using stefanfrings::HttpSession;
+
+UpdateComicController::UpdateComicController() { }
 
 void UpdateComicController::service(HttpRequest &request, HttpResponse &response)
 {
