@@ -11,7 +11,10 @@
 
 #include "QsLog.h"
 
-UpdateComicControllerV2::UpdateComicControllerV2() {}
+using stefanfrings::HttpRequest;
+using stefanfrings::HttpResponse;
+
+UpdateComicControllerV2::UpdateComicControllerV2() { }
 
 void UpdateComicControllerV2::service(HttpRequest &request, HttpResponse &response)
 {
